require 'spec_helper'

describe Users::ContributionsController do
  subject{ response }
  let(:user){ create(:user, password: 'current_password', password_confirmation: 'current_password', authorizations: [create(:authorization, uid: 666, oauth_provider: create(:oauth_provider, name: 'facebook'))]) }
  let(:successful_project){ create(:project, state: 'online', user: user) }
  let(:failed_project){ create(:project, state: 'online') }
  let(:successful_contribution){ create(:contribution, state: 'confirmed', project: successful_project, user: user) }
  let(:failed_contribution){ create(:contribution, state: 'confirmed', user: user, project: failed_project) }
  let(:other_back) { create(:contribution, project: failed_project) }
  let(:unconfirmed_contribution) { create(:contribution, state: 'pending', user: user, project: failed_project) }
  let(:current_user){ nil }
  let(:format){ 'json' }
  before do
    controller.stub(:current_user).and_return(current_user)
    successful_contribution
    failed_contribution
    unconfirmed_contribution
    other_back
    successful_project.update_attributes state: 'successful'
    failed_project.update_attributes state: 'failed'
  end

  describe "GET index" do
    let(:current_user){ user }

    before do
      get :index, user_id: successful_contribution.user.id, locale: 'pt'
    end

    its(:status){ should == 200 }
  end

  describe "POST request_refund" do
    before do
      ContributionObserver.any_instance.stub(:notify_backoffice)
    end

    context "without user" do
      let(:current_user){ nil }
      before { post :request_refund, { user_id: user.id, id: failed_contribution.id } }

      it "should not set requested_refund" do
        failed_contribution.reload
        failed_contribution.requested_refund?.should be_false
      end
      it{ should redirect_to new_user_session_path }
    end

    context "when current_user have a confirmed contribution" do
      let(:current_user) { user }
      before { post :request_refund, { user_id: user.id, id: failed_contribution.id } }

      it do
        failed_contribution.reload
        failed_contribution.requested_refund?.should be_true
      end

      it { should redirect_to credits_user_path(current_user) }
    end

    context "when current_user have a unconfirmed contribution" do
      let(:current_user) { user }
      before { post :request_refund, { user_id: user.id, id: unconfirmed_contribution.id } }

      it do
        unconfirmed_contribution.reload
        unconfirmed_contribution.requested_refund?.should be_false
      end

      it { should redirect_to credits_user_path(current_user) }
    end

    context "when current_user is not owner of the contribution" do
      let(:current_user) { create(:user) }
      let(:user) { other_back.user }
      before { post :request_refund, { user_id: user.id, id: other_back.id } }

      it do
        other_back.reload
        other_back.requested_refund?.should be_false
      end

      it { should redirect_to root_path }
    end
  end
end
